@@ -5,20 +5,19 @@ permutations <- function (n) {
     else if (n < 2) 
         stop("n must be a positive integer")
     z <- matrix(1)
-    for (i in 2:n) {
+    for (i in seq_len(n)[-1]) {
         x <- cbind(z, i)
-        a <- c(1:i, 1:(i - 1))
+        a <- c(seq_len(i), seq_len(i)[-i])
         z <- matrix(0, ncol = ncol(x), nrow = i * nrow(x))
-        z[1:nrow(x), ] <- x
-        for (j in 2:i - 1) {
-            z[j * nrow(x) + 1:nrow(x), ] <- x[, a[1:i + j]]
+        z[seq_len(nrow(x)), ] <- x
+        for (j in seq_len(i)[-1] - 1) {
+            z[j * nrow(x) + seq_len(nrow(x)), ] <- x[, a[seq_len(i) + j]]
         }
     }
     dimnames(z) <- NULL
     z
 }
 
-
 Sort <- function(x, by = NULL) {
   if (!(inherits(x, "jags") && inherits(x$model, "BMMmodel"))) 
     stop("Use only with 'jags' objects with model of class 'BMMmodel'.")
@@ -40,11 +39,11 @@ Sort <- function(x, by = NULL) {
     }
     else if (length(levels(as.factor(x$results[,ii]))) == x$model$data$k) {
       ps <- permutations(x$model$data$k)
-      for (j in 1:dim(ps)[1]) {
+      for (j in seq_len(nrow(ps))) {
         ps1 <- ps[j,]
         index <- apply(ind, 2, function(x) all(x == ps1))
         if (any(index)) {
-          dummy <- factor(x$results[index,ii], levels = 1:x$model$data$k)
+          dummy <- factor(x$results[index,ii], levels = seq_len(x$model$data$k))
           levels(dummy) <- order(ps1)
           x$results[index,ii] <- as.numeric(levels(dummy))[as.integer(dummy)]
         }
